@@ -17,7 +17,8 @@ class FeedbackCreateView(CreateView):
         kwargs = super(FeedbackCreateView, self).get_form_kwargs()
         if self.request.user.is_authenticated():
             kwargs.update({'user': self.request.user})
-        kwargs.update({'url': self.request.path})
+        kwargs.update({
+            'url': self.request.META.get('HTTP_REFERER', self.request.path)})
         return kwargs
 
     def get_template_names(self):
